@@ -1,3 +1,15 @@
+#' get.default.parameters
+#'
+#' @keywords internal
+#'
+get.default.parameters <- function(mcall, myFormals) {
+  ## formals with default arguments
+  for ( v in names(myFormals)){
+    if (!(v %in% names(mcall)))
+      mcall[v] <- myFormals[v]  ## if arg is missing I add it
+  }
+  return(mcall)
+}
 
 #' get_test_less_predict
 #'
@@ -56,7 +68,10 @@ max_col <- function(m){
 #'
 numeric_to_predict <- function(real, predic.var = NULL) {
   if(is.numeric(predic.var)) {
-    predic.var <- factor(predic.var, labels = levels(real))
+    numCategories <-  length(levels(real))
+    #We must specify the possible values that the factor type object can take
+    #Then we specify the labels that must have the same size as the levels
+    predic.var <- factor(predic.var, levels = 1:numCategories,labels = levels(real))
   }
   predic.var
 }
